@@ -23,7 +23,7 @@ else
     echo -e "\e[1;32mInstalling prerequisites.....\e[0m"
     sudo apt-get install python3-pip python3-venv
     echo -e "\e[1;32m\nprerequisites installed\e[0m"
-    echo -e "\e[1;33m\nSearch for available scripts that create python virtual environments for different task types using nelow command:\e[0m"
+    echo -e "\e[1;33m\nSearch for available scripts that create python virtual environments for different task types using below command:\e[0m"
     echo -e "\e[1;34m\ncommand:find external/ -name init_venv.sh\e[0m"
     echo -e "\e[1;35m\nInorder to further continue working with training-extension follow the below mentioned link:\nhttps://github.com/openvinotoolkit/training_extensions/blob/develop/QUICK_START_GUIDE.md\e[0m"
 
